# aio9p

Asyncio-based bindings for the 9P protocol. Work in progress, littered with print-debugs. A working example for the 9P2000 dialect is implemented in aio9p.example.simple .

# TODO

- Support for 9P2000.u and 9P2000.L dialects
- Separation between protocol parser-formatters and the classes used for implementation subclassing
- Logging
- Significantly more tests
